summaryrefslogtreecommitdiffstats
path: root/src/H5Odtype.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/H5Odtype.c')
-rw-r--r--src/H5Odtype.c24
1 files changed, 7 insertions, 17 deletions
diff --git a/src/H5Odtype.c b/src/H5Odtype.c
index 26bb58d..e68d352 100644
--- a/src/H5Odtype.c
+++ b/src/H5Odtype.c
@@ -66,9 +66,7 @@ static hbool_t interface_initialize_g = FALSE;
*
* Purpose: Decodes a data type
*
* Return: Success: SUCCEED
*
* Failure: FAIL
*
* Programmer: Robb Matzke
* Monday, December 8, 1997
@@ -243,9 +241,7 @@ H5O_dtype_decode_helper(const uint8 **pp, H5T_t *dt)
*
* Purpose: Encodes a data type.
*
* Return: Success: SUCCEED
*
* Failure: FAIL
*
* Programmer: Robb Matzke
* Monday, December 8, 1997
@@ -538,7 +534,7 @@ H5O_dtype_decode(H5F_t __unused__ *f, const uint8 *p,
const uint8 *p; IN: the raw information buffer
const void *mesg; IN: Pointer to the simple datatype struct
RETURNS
- SUCCEED/FAIL
+ Non-negative on success/Negative on failure
DESCRIPTION
This function encodes the native memory form of the simple datatype
message in the "raw" disk form.
@@ -667,9 +663,7 @@ H5O_dtype_size(H5F_t *f, const void *mesg)
* Purpose: Frees resources within a data type message, but doesn't free
* the message itself.
*
* Return: Success: SUCCEED
*
* Failure: FAIL
*
* Programmer: Robb Matzke
* Tuesday, December 9, 1997
@@ -705,9 +699,7 @@ H5O_dtype_reset(void *_mesg)
* Purpose: Returns information about where the shared message is located
* by filling in the SH shared message struct.
*
* Return: Success: SUCCEED
*
* Failure: FAIL
*
* Programmer: Robb Matzke
* Monday, June 1, 1998
@@ -744,9 +736,7 @@ H5O_dtype_get_share (H5F_t __unused__ *f, const void *_mesg,
*
* Purpose: Copies sharing information from SH into the message.
*
* Return: Success: SUCCEED
*
* Failure: FAIL
*
* Programmer: Robb Matzke
* Thursday, June 4, 1998
@@ -786,7 +776,7 @@ H5O_dtype_set_share (H5F_t __unused__ *f, void *_mesg/*in,out*/,
intn indent; IN: Amount to indent information by
intn fwidth; IN: Field width (?)
RETURNS
- SUCCEED/FAIL
+ Non-negative on success/Negative on failure
DESCRIPTION
This function prints debugging output to the stream passed as a
parameter.
@@ -66,9 +66,7 @@ static hbool_t interface_initialize_g = FALSE;
* Purpose: Decodes a data type
*
- * Return: Success: SUCCEED
- *
- * Failure: FAIL
+ * Return: Non-negative on success/Negative on failure
*
* Programmer: Robb Matzke
@@ -243,9 +241,7 @@ H5O_dtype_decode_helper(const uint8 **pp, H5T_t *dt)
* Purpose: Encodes a data type.
*
- * Return: Success: SUCCEED
- *
- * Failure: FAIL
+ * Return: Non-negative on success/Negative on failure
*
* Programmer: Robb Matzke
@@ -667,9 +663,7 @@ H5O_dtype_size(H5F_t *f, const void *mesg)
* the message itself.
*
- * Return: Success: SUCCEED
- *
- * Failure: FAIL
+ * Return: Non-negative on success/Negative on failure
*
* Programmer: Robb Matzke
@@ -705,9 +699,7 @@ H5O_dtype_reset(void *_mesg)
* by filling in the SH shared message struct.
*
- * Return: Success: SUCCEED
- *
- * Failure: FAIL
+ * Return: Non-negative on success/Negative on failure
*
* Programmer: Robb Matzke
@@ -744,9 +736,7 @@ H5O_dtype_get_share (H5F_t __unused__ *f, const void *_mesg,
* Purpose: Copies sharing information from SH into the message.
*
- * Return: Success: SUCCEED
- *
- * Failure: FAIL
+ * Return: Non-negative on success/Negative on failure
*
* Programmer: Robb Matzke